@@ -1,8 +1,8 @@
 #' Retrieve snapshot tables
 #' @description Retrieves data and colour information from the snapshot tables.
-#' @keywords internal
+#' @noRd
 
-retrieve_tables <- function(itemNum, smallsetTables) {
+retrieve_tables <- function(itemNum, smallsetTables, ignoreCols) {
   # Retrieve table colours
   tab1 <-
     as.data.frame(smallsetTables[[1]][[itemNum]]$body$styles$text$color$data)
@@ -10,6 +10,9 @@ retrieve_tables <- function(itemNum, smallsetTables) {
   # Retrieve table data
   tab2 <-
     as.data.frame(smallsetTables[[1]][[itemNum]]$body$dataset)
+  if (!is.null(ignoreCols)) {
+    tab2 <- tab2[,!colnames(tab2) %in% ignoreCols]
+  }
   
   return(list(tab1, tab2))
   
